==> cms-db_v0.9.tar.gz: admin/newinc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('includes');
include('locale.inc.php');
$locale = new LocalizingClass('includes');

if(isset($_POST['submit'])) {
	$name = $_POST['name'];
	if (!preg_match('/[^a-z0-9_-]/i', $name)) {
		if (!file_exists('../data/includes/'.$name)) {
			if (!copy('./newfile', '../data/includes/'.$name)) {
				include('error.inc.php');
				throw_error(locale('desc_new-error-copy',true), 'includes.php?'.SID.csrf_protection_get());
			}
			header('Location: editinc.php?inc='.$name.'&'.SID.csrf_protection_get());
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-name',true), 'includes.php?'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-specialchars',true), 'includes.php?'.SID.csrf_protection_get());
	}
} else {
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_newinc') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>

		<h1><?php locale('title_newinc') ?></h1>

		<form action="newinc.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
			<fieldset>
				<p>
					<?php locale('desc_newinc') ?>
				</p>
				<p>
					<input type="text" name="name" value="" size="24" />
				</p>
			</fieldset>
			<input type="submit" name="submit" value="<?php locale('button_create') ?>" />
		</form>

	</body>
</html>
<?php } ?>

==> cms-db_v0.9.3.tar.gz: admin/newinc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('includes');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('includes');

if(isset($_POST['submit'])) {
	$name = $_POST['name'];
	if (!preg_match('/[^a-z0-9_-]/i', $name)) {
		if (!file_exists('../data/includes/'.$name)) {
			if (!copy('./newfile', '../data/includes/'.$name)) {
				include('error.inc.php');
				throw_error(locale('desc_new-error-copy',true), 'includes.php?'.SID.csrf_protection_get());
			}
			header('Location: editinc.php?inc='.$name.'&'.SID.csrf_protection_get());
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-name',true), 'includes.php?'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-specialchars',true), 'includes.php?'.SID.csrf_protection_get());
	}
} else {
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_newinc') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>

		<h1><?php locale('title_newinc') ?></h1>

		<form action="newinc.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
			<fieldset>
				<p>
					<?php locale('desc_newinc') ?>
				</p>
				<p>
					<input type="text" name="name" value="" size="24" />
				</p>
			</fieldset>
			<input type="submit" name="submit" value="<?php locale('button_create') ?>" />
		</form>

	</body>
</html>
<?php } ?>
